@@ -1,7 +1,7 @@
 from .value import equal_to, not_equal_to, greater_than, greater_than_or_equal_to, \
     less_than, less_than_or_equal_to, is_between, is_none, is_not_none, has_length, is_true, is_false
 from .string import starts_with, ends_with, contains_string, match_pattern, is_text, is_json
-from .list_ import has_item, has_items, has_only_items, is_in
+from .list_ import has_item, has_items, has_only_items, has_all_items, is_in
 from .dict_ import has_entry
 from .types_ import is_integer, is_float, is_bool, is_str, is_dict, is_list
 from .composites import all_of, any_of, anything, something, existing, present, is_, not_, is_not
