@@ -7,8 +7,9 @@ Created on Sep 8, 2016
 import inspect
 import copy
 
-from typing import Any, Iterable, Callable, Optional, Tuple
+from typing import Any, Iterable, Callable, Optional, Tuple, Sequence, Union
 
+from lemoncheesecake.helpers.text import STRING_TYPES
 from lemoncheesecake.suite.core import InjectedFixture, Test
 
 
@@ -93,7 +94,7 @@ def suite(description=None, name=None, rank=None):
 
 def test(description=None, name=None):
     """
-    Decorator, make a method as a test method.
+    Decorator, mark a function/method as a test.
 
     :param description: test's description
     :param name: test's name (by default, the suite's name is taken from the class's name)
@@ -192,25 +193,63 @@ def _default_naming_scheme(name, description, parameters, nb):
     return name + "_%d" % nb, description + " #%d" % nb
 
 
+def _format_naming_scheme(name_fmt, description_fmt):
+    def naming_scheme(_, __, parameters, ___):
+        return name_fmt.format(**parameters), description_fmt.format(**parameters)
+    return naming_scheme
+
+
 class _Parametrized(object):
     def __init__(self, parameters_source, naming_scheme):
-        self.parameters_source = parameters_source
+        self._parameters_source = parameters_source
         self.naming_scheme = naming_scheme
 
+    @property
+    def parameters_source(self):
+        source = iter(self._parameters_source)
+        try:
+            first_item = next(source)
+        except StopIteration:
+            return
+        if type(first_item) is dict:
+            yield first_item
+            for item in source:
+                yield item
+        else:
+            if type(first_item) in STRING_TYPES:
+                names = [s.strip() for s in first_item.split(",")]
+            else:
+                names = first_item  # assume list or tuple
+            for values in source:
+                yield dict(zip(names, values))
+
 
 def parametrized(parameter_source, naming_scheme=_default_naming_scheme):
-    # type: (Iterable[dict], Optional[Callable[[str, str, dict, int], Tuple[str, str]]]) -> Any
+    # type: (Iterable, Optional[Union[Callable[[str, str, dict, int], Tuple[str, str]], Sequence]]) -> Any
     """
     Decorator, make the test parametrized.
 
-    :param parameter_source: a list / iterable of dicts, each dict represent the parameters that will be used
-        by the test
-    :param naming_scheme: a optional function that takes as parameters the base test name, description, parameters, index
-         and must return the expanded test name and description as a two elements list
+    :param parameter_source: it can be either:
+
+        -  an iterable of dicts, each dict representing the arguments passed to the test
+
+        - a CSV-like mode, where the first element of the list represents the argument names as an str or a sequence
+          (example: ``"i,j"`` or ``("i", "j")``) and the remaining elements are sequences of the arguments to be
+          passed to the test.
+
+    :param naming_scheme: optional, it can be either:
+
+      - a optional function that takes as parameters the base test name, description, parameters, index
+        and must return the expanded test name and description as a two elements list
+
+      - a tuple/list of two (name + description) format strings, example: ``("test_{i}_plus_{j}", "Test {i} plus {j}")``
     """
 
     def wrapper(obj):
         md = get_metadata(obj)
-        md.parametrized = _Parametrized(parameter_source, naming_scheme)
+        md.parametrized = _Parametrized(
+            parameter_source,
+            naming_scheme if callable(naming_scheme) else _format_naming_scheme(*naming_scheme)
+        )
         return obj
     return wrapper
